"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DbRegistry = void 0;
class DbRegistry {
  items = {};
  register(input) {
    const key = `${input.app}-${input.tags.sort().join("-")}`;
    if (this.items[key]) {
      throw new Error(`Item with app "${input.app}" and tags "${input.tags.join(", ")}" is already registered.`);
    }
    this.items[key] = input;
  }
  getOneItem(cb) {
    const item = this.getItem(cb);
    if (!item) {
      throw new Error("Item not found.");
    }
    return item;
  }
  getItem(cb) {
    const items = this.getItems(cb);
    if (items.length === 0) {
      return null;
    } else if (items.length > 1) {
      throw new Error("More than one item found with the provided criteria.");
    }
    return items[0];
  }
  getItems(cb) {
    const results = [];
    for (const key in this.items) {
      const item = this.items[key];
      if (cb(item)) {
        results.push(item);
      }
    }
    return results;
  }
}
exports.DbRegistry = DbRegistry;

//# sourceMappingURL=DbRegistry.js.map